"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const common_2 = require("@pardjs/common");
const axios_1 = __importDefault(require("axios"));
const constants_1 = require("./constants");
let PardjsUsersService = class PardjsUsersService {
    constructor() {
        this.httpService = axios_1.default.create({
            baseURL: constants_1.PARDJS_AUTH_SERVICE_BASE_URL,
        });
        common_2.logger.info('users service base url', { PARDJS_AUTH_SERVICE_BASE_URL: constants_1.PARDJS_AUTH_SERVICE_BASE_URL });
    }
    registerAuthPoints(data) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = yield this.getWhiteListUserToken();
            yield this.httpService.post('/auth-points/actions/register?access_token=' + token, data);
            return true;
        });
    }
    getWhiteListUserToken() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.whiteListUserToken) {
                try {
                    const canAccess = yield this.canAccess(this.whiteListUserToken);
                    if (canAccess) {
                        return this.whiteListUserToken;
                    }
                }
                catch (error) {
                    // Just for preventing error be thrown.
                }
            }
            const token = yield this.loginWhiteListUser();
            this.whiteListUserToken = token;
            return token;
        });
    }
    loginWhiteListUser() {
        return __awaiter(this, void 0, void 0, function* () {
            const url = '/login-by-ip';
            try {
                // TODO: LoginResponse as the return type
                const res = yield this.httpService.post(url);
                return res.data.token;
            }
            catch (err) {
                this.handleError(err, 'loginWhiteListUser', url);
            }
        });
    }
    canAccess(token, authPointName) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = '/users/me/actions/check-access?access_token=' + token + '&authPointName=' + authPointName;
            try {
                const res = yield this.httpService.get(url);
                return res.data;
            }
            catch (err) {
                this.handleError(err, 'canAccess', url);
            }
        });
    }
    handleError(err, methodName, url) {
        common_2.logger.error('http error when checking access', { errMessage: err.message });
        if (!err.response) {
            common_2.logger.error('connection failed', { err, methodName, url });
            throw new common_1.InternalServerErrorException({
                type: 'CONNECT_PARDJS_USERS_SERVER_FAILED',
                message: 'connect to pardjs users service failed.',
            });
        }
        const res = err.response;
        if (res.status === common_1.HttpStatus.UNAUTHORIZED) {
            throw new common_1.UnauthorizedException(res.data.error);
        }
        throw new common_1.BadRequestException(res.data.error);
    }
};
PardjsUsersService = __decorate([
    common_1.Injectable()
], PardjsUsersService);
exports.PardjsUsersService = PardjsUsersService;
//# sourceMappingURL=service.js.map